
# choochoo (ch2)

An **open**, **hackable** and **free** training diary.

I wrote this mainly for myself, but perhaps it will also be attractive to 
others who want a way to track and plan their progress that is open, 
lightweight and extensible.

The main interface is a curses-style diary, used to track daily activity
as well as progress towards aims.  A flexible "schedule spec" is used to
define periodic events (eg training routines) and (unfortunately) there's 
dedicated fuctionality for tracking injuries.

[See Documentation](https://andrewcooke.github.io/choochoo/)
